[![img](https://img.shields.io/badge/Made_in-Doom_Emacs-blue?style=for-the-badge)](https://github.com/hlissner/doom-emacs)
[![img](https://img.shields.io/badge/follow_me-@alka1e-E4405F?style=for-the-badge&logo=instagram&labelColor=8f3c4c&logoColor=white)](https://www.instagram.com/alka1e)
[![img](https://img.shields.io/badge/follow_me-@alka1e-1DA1F2?style=for-the-badge&logo=twitter&labelColor=27597a&logoColor=white)](https://twitter.com/alka1e)

# Devinstaller Core

[![img](https://img.shields.io/badge/work_in-progress-eb3434?style=for-the-badge&labelColor=7d1616)]()
[![img](https://img.shields.io/badge/license-mit-blueviolet?style=for-the-badge)]()
[![Documentation Status](https://readthedocs.org/projects/devinstaller-core/badge/?version=latest&style=for-the-badge)](https://devinstaller-core.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gl/devinstaller/devinstaller-core-py/branch/master/graph/badge.svg)](https://codecov.io/gl/devinstaller/devinstaller-core-py)
[![pipeline status](https://gitlab.com/devinstaller/devinstaller-core-py/badges/master/pipeline.svg)](https://gitlab.com/devinstaller/devinstaller-core-py/-/commits/master)

## Table of Contents

[[_TOC_]]

# What is Devinstaller Core?

Devinstaller Core is the Python implementation for the Devinstaller Specification and the core library for other Devinstaller applications.

This package is not meant to be used as is. You are supposed to create applications using this library.

This Core package provided everything you need to read, parse and execute any `spec-file` and `prog-file`.

[For more info ReadTheDocs](#full-documentation)

# Full Documentation

Main page: [Read the docs](https://devinstaller-core.readthedocs.io/en/latest/)

| Topic              | Documentation link                                                       |
| ------------------ | ------------------------------------------------------------------------ |
| The Design process | <https://devinstaller-core.readthedocs.io/en/latest/design_process.html> |
| Terminology        | TODO                                                                     |
| Implementation     | <https://devinstaller-core.readthedocs.io/en/latest/implementation.html> |
| API                | <https://devinstaller-core.readthedocs.io/en/latest/api.html>            |
| Contributing       | <https://devinstaller-core.readthedocs.io/en/latest/contributing.html>   |

_Remaining docs are WIP_

# License

Licensed under the terms of [MIT License](LICENSE.md)

---

[![forthebadge](https://forthebadge.com/images/badges/uses-git.svg)](https://forthebadge.com)
[![forthebadge](https://forthebadge.com/images/badges/approved-by-george-costanza.svg)](https://forthebadge.com)
[![forthebadge](https://forthebadge.com/images/badges/certified-snoop-lion.svg)](https://forthebadge.com)
